==> vue-components-1.5.13.tgz: package/lib/form/src/shared/ValidationMessage.vue.rd.js <==
import { pt as a } from "@regiondev/vue-utils";
import { defineComponent as v, toRefs as x, computed as s, openBlock as i, createElementBlock as r, createVNode as N, Transition as C, withCtx as R, unref as n, normalizeClass as c, createElementVNode as l, toDisplayString as S, createCommentVNode as g } from "vue";
import { debouncedRef as m } from "@vueuse/core";
import { InputState as e } from "./enums/state.enum.rd.js";
const E = { class: "relative pb-10 mt-0.5 overflow-hidden input-animation" }, b = { class: "mb-0 pb-0 ml-1 color-inherit" }, U = /* @__PURE__ */ v({
  __name: "ValidationMessage",
  props: {
    state: a.oneOf(["success", "warning", "error", "none"]).def("none"),
    hint: a.string
  },
  setup(d) {
    const u = d, { state: p, hint: _ } = x(u), t = m(p, 100), o = m(_, 100), f = s(() => ({
      "text-red-500": t.value == e.ERROR,
      "text-yellow-500": t.value == e.WARNING,
      "text-green-500": t.value == e.SUCCESS,
      "text-blue-500": t.value == e.NONE
    })), h = s(() => {
      switch (t.value) {
        case e.ERROR:
          return "i-heroicons-solid:exclamation-circle";
        case e.SUCCESS:
          return "i-heroicons-solid:check-circle";
        case e.WARNING:
          return "i-heroicons-solid:exclamation";
        case e.NONE:
          return "i-heroicons-solid:information-circle";
      }
    });
    return (w, O) => (i(), r("div", E, [
      N(C, {
        "enter-active-class": "animate__animated animate__fadeInDown",
        "leave-active-class": "animate__animated animate__fadeOutUp"
      }, {
        default: R(() => [
          n(o) ? (i(), r("span", {
            key: 0,
            class: c([n(f), "absolute flex items-center top-0"])
          }, [
            l("span", {
              class: c([n(h), "color-inherit p-3 text-lg"])
            }, null, 2),
            l("p", b, S(n(o)), 1)
          ], 2)) : g("", !0)
        ]),
        _: 1
      })
    ]));
  }
});
export {
  U as default
};

==> vue-components-1.5.18.tgz: package/lib/form/src/shared/ValidationMessage.vue.rd.js <==
import { pt as a } from "@regiondev/vue-utils";
import { defineComponent as v, toRefs as x, computed as s, openBlock as i, createElementBlock as r, createVNode as N, Transition as C, withCtx as R, unref as n, normalizeClass as c, createElementVNode as l, toDisplayString as S, createCommentVNode as g } from "vue";
import { debouncedRef as m } from "@vueuse/core";
import { InputState as e } from "./enums/state.enum.rd.js";
const E = { class: "relative pb-10 mt-0.5 overflow-hidden input-animation" }, b = { class: "fs-smaller mb-0 pb-0 ml-1 color-inherit" }, U = /* @__PURE__ */ v({
  __name: "ValidationMessage",
  props: {
    state: a.oneOf(["success", "warning", "error", "none"]).def("none"),
    hint: a.string
  },
  setup(d) {
    const u = d, { state: p, hint: f } = x(u), t = m(p, 100), o = m(f, 100), _ = s(() => ({
      "text-red-500": t.value == e.ERROR,
      "text-yellow-500": t.value == e.WARNING,
      "text-green-500": t.value == e.SUCCESS,
      "text-blue-500": t.value == e.NONE
    })), h = s(() => {
      switch (t.value) {
        case e.ERROR:
          return "i-heroicons-solid:exclamation-circle";
        case e.SUCCESS:
          return "i-heroicons-solid:check-circle";
        case e.WARNING:
          return "i-heroicons-solid:exclamation";
        case e.NONE:
          return "i-heroicons-solid:information-circle";
      }
    });
    return (w, O) => (i(), r("div", E, [
      N(C, {
        "enter-active-class": "animate__animated animate__fadeInDown",
        "leave-active-class": "animate__animated animate__fadeOutUp"
      }, {
        default: R(() => [
          n(o) ? (i(), r("span", {
            key: 0,
            class: c([n(_), "absolute flex items-center top-0"])
          }, [
            l("span", {
              class: c([n(h), "color-inherit p-3 text-lg"])
            }, null, 2),
            l("p", b, S(n(o)), 1)
          ], 2)) : g("", !0)
        ]),
        _: 1
      })
    ]));
  }
});
export {
  U as default
};
